@@ -25,7 +25,9 @@ BookDB::Schema::Result::Book->add_columns(
   "isbn",
   { data_type => "varchar", is_nullable => 0, size => 100 },
   "title",
-  { data_type => "varchar", is_nullable => 0, size => 100 },
+  { data_type => "varchar", is_nullable => 0, size => 100,
+    extra => { field_def => { type => 'TextArea', size => '64', temp => 'testing' } },
+  },
   "author",
   { data_type => "varchar", is_nullable => 0, size => 100 },
   "publisher",
